﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.UltraChart.Core.Layers;

namespace CompositeChart
{
    public partial class Form1 : Form
    {
        private DataTable dt;
        private int count =6;
        private Random rnd;

        private AxisItem axisX;
        private AxisItem axisY;
        private AxisItem axisX2;
        private AxisItem axisY2;

        private XYSeries series2;

        private ChartLayerAppearance myColumnLayer;
        private ChartLayerAppearance myColumnLayer2;
        private LineAppearance la;

        public Form1()
        {
            InitializeComponent();
            rnd = new Random();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.ultraChart1.ChartType = ChartType.Composite;

            ChartArea area = new ChartArea();
            this.ultraChart1.CompositeChart.ChartAreas.Add(area);

            dt = new DataTable();
            dt.Columns.Add("Period", typeof(DateTime));
            dt.Columns.Add("Value", typeof(double));
            dt.Rows.Add(DateTime.Now.AddDays(1), 10);
            dt.Rows.Add(DateTime.Now.AddDays(2), 15);
            dt.Rows.Add(DateTime.Now.AddDays(3), 5);
            dt.Rows.Add(DateTime.Now.AddDays(4), 25);
            dt.Rows.Add(DateTime.Now.AddDays(5), 20);


            axisX = new AxisItem();
            axisX.DataType = AxisDataType.Time;
            axisX.OrientationType = AxisNumber.X_Axis;
            axisX.Labels.ItemFormat = AxisItemLabelFormat.ItemLabel;
            axisX.Labels.ItemFormatString = "<ITEM_LABEL:dd:MM:yyyy>";
            axisX.SetLabelAxisType = SetLabelAxisType.ContinuousData;
            axisX.TimeAxisStyle.TimeAxisStyle = RulerGenre.Discrete;
            axisX.LineThickness = 2;
            axisX.LineEndCapStyle = LineCapStyle.ArrowAnchor;
            axisX.Labels.Orientation = TextOrientation.VerticalLeftFacing;
            axisX.Labels.VerticalAlign = StringAlignment.Far;
            axisX.LineColor = Color.Blue;
            axisX.ScrollScale.Visible = true;
            axisX.Visible = false;


            axisX.TickmarkStyle = AxisTickStyle.Smart;
            axisX.TickmarkInterval = 7;
            axisX.TickmarkIntervalType = AxisIntervalType.Days;

            area.Axes.Add(axisX);

            axisY = new AxisItem();
            axisY.Extent = 20;
            axisY.DataType = AxisDataType.Numeric;
            axisY.Labels.ItemFormatString = "<DATA_VALUE:##.##>";
            axisY.OrientationType = AxisNumber.Y_Axis;
            axisY.LineColor = Color.Blue;
            axisY.Visible = false;
            area.Axes.Add(axisY);

            myColumnLayer = new ChartLayerAppearance();
            myColumnLayer.ChartType = ChartType.LineChart;
            myColumnLayer.ChartArea = area;



            NumericTimeSeries series1 = new NumericTimeSeries();
            series1.Label = "test";
            series1.DataBind(dt, "Period", "Value");
            series1.PEs.Add(new PaintElement(Color.Red));
            myColumnLayer.Series.Add(series1);
            ultraChart1.CompositeChart.Series.Add(series1);
            myColumnLayer.AxisX = axisX;
            myColumnLayer.AxisY = axisY;

            this.ultraChart1.CompositeChart.ChartLayers.Add(myColumnLayer);


            la = new LineAppearance(ultraChart1);
            la.IconAppearance.Icon = SymbolIcon.Circle;
            la.IconAppearance.IconSize = SymbolIconSize.Large;
            la.LineStyle.EndStyle = LineCapStyle.DiamondAnchor;

            LineChartAppearance dd = new LineChartAppearance();
            dd.LineAppearances.Add(la);
            myColumnLayer.ChartTypeAppearance = dd;


            ultraComboEditor1.Items.Add(SymbolIcon.Circle);
            ultraComboEditor1.Items.Add(SymbolIcon.Diamond);
            ultraComboEditor1.Items.Add(SymbolIcon.Plus);
            ultraComboEditor1.Items.Add(SymbolIcon.Square);
            ultraComboEditor1.Items.Add(SymbolIcon.Triangle);
            ultraComboEditor1.Items.Add(SymbolIcon.X);


            axisX2 = new AxisItem();
            axisX2.Extent = 40;
            axisX2.DataType = AxisDataType.Numeric;
            axisX2.OrientationType = AxisNumber.X_Axis;
            axisX2.SetLabelAxisType = SetLabelAxisType.ContinuousData;
            axisX2.LineColor = Color.Blue;
            axisX2.LineThickness = 2;
            area.Axes.Add(axisX2);


            axisY2 = new AxisItem();
            axisY2.Extent = 60;
            axisY2.DataType = AxisDataType.Numeric;
            axisY2.Labels.ItemFormatString = "<DATA_VALUE:##.##>";
            axisY2.OrientationType = AxisNumber.Y_Axis;
            axisY2.LineColor = Color.Blue;
            area.Axes.Add(axisY2);

            myColumnLayer2 = new ChartLayerAppearance();
            myColumnLayer2.ChartType = ChartType.ScatterChart;
            myColumnLayer2.ChartArea = area;


            series2 = new XYSeries();
            series2.Label = "test";

            series2.PEs.Add(new PaintElement(Color.Red));
            myColumnLayer2.Series.Add(series2);
            ultraChart1.CompositeChart.Series.Add(series2);
            myColumnLayer2.AxisX = axisX2;
            myColumnLayer2.AxisY = axisY2;
            this.ultraChart1.CompositeChart.ChartLayers.Add(myColumnLayer2);

        }

        private void ultraButton1_Click(object sender, EventArgs e)
        {
            double val = (double)rnd.Next(0, 100);
            count++;

            if (dt.Rows.Count == 0)
            {
                series2.Points.Add(new XYDataPoint(0.001, 0.001, "Test", false));
                dt.Rows.Add(DateTime.Now.AddDays(count), null);
                myColumnLayer.Visible = false;
                axisX.Visible = false;
                axisY.Visible = false;

                myColumnLayer2.Visible = true;
                axisX2.Visible = true;
                axisY2.Visible = true;

            }
            else
            {
                dt.Rows.Add(DateTime.Now.AddDays(count), val);
                myColumnLayer.Visible = true;
                axisX.Visible = true;
                axisY.Visible = true;

                myColumnLayer2.Visible = false;
                axisX2.Visible = false;
                axisY2.Visible = false;
            }
        }

        private void ultraButton2_Click(object sender, EventArgs e)
        {
            if (!myColumnLayer.Visible) return;
            count++;
            dt.Rows.Add(DateTime.Now.AddDays(count), null);
        }

        private void ultraButton3_Click(object sender, EventArgs e)
        {
            ultraChart1.Image.Save(@"..\\..\\Test.Wmf", System.Drawing.Imaging.ImageFormat.Wmf);
        }

        private void ultraComboEditor1_ValueChanged(object sender, EventArgs e)
        {
            la.IconAppearance.Icon = (SymbolIcon)ultraComboEditor1.Value;
        }

    }
}